==> livingdoc-maven-plugin-2.4-sources.jar: ch/ifocusit/livingdoc/plugin/utils/AnnotationUtil.java <==
/*
 * Living Documentation
 *
 * Copyright (C) 2023 Focus IT
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package ch.ifocusit.livingdoc.plugin.utils;

import java.lang.annotation.Annotation;
import java.lang.reflect.Field;
import java.util.Optional;

/**
 * @author Julien Boz
 */
public class AnnotationUtil {

    public static <T extends Annotation> Optional<T> tryFind(Field field, Class<T> annotationClass) {
        return annotationClass == null ? Optional.empty() : field.isAnnotationPresent(annotationClass) ?
                Optional.of(field.getAnnotation(annotationClass)) : Optional.empty();
    }

    public static <T extends Annotation> Optional<T> tryFind(Class clazz, Class<T> annotationClass) {
        return annotationClass == null ? Optional.empty() : clazz.isAnnotationPresent(annotationClass) ?
                Optional.of(annotationClass.cast(clazz.getAnnotation(annotationClass))) : Optional.empty();
    }
}

==> livingdoc-maven-plugin-2.10-sources.jar: ch/ifocusit/livingdoc/plugin/utils/AnnotationUtil.java <==
/*
 * Living Documentation
 *
 * Copyright (C) 2024 Focus IT
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package ch.ifocusit.livingdoc.plugin.utils;

import java.lang.annotation.Annotation;
import java.lang.reflect.Field;
import java.util.Optional;

/**
 * @author Julien Boz
 */
public class AnnotationUtil {

    public static <T extends Annotation> Optional<T> tryFind(Field field, Class<T> annotationClass) {
        return annotationClass == null ? Optional.empty()
                : field.isAnnotationPresent(annotationClass) ? Optional.of(field.getAnnotation(annotationClass))
                        : Optional.empty();
    }

    public static <T extends Annotation> Optional<T> tryFind(Class clazz, Class<T> annotationClass) {
        return annotationClass == null ? Optional.empty()
                : clazz.isAnnotationPresent(annotationClass)
                        ? Optional.of(annotationClass.cast(clazz.getAnnotation(annotationClass)))
                        : Optional.empty();
    }
}
